/* $Id: ComboBox.h,v 1.11 1999/11/06 05:50:57 glgay Exp $ */
/*
 Copyright (C) 1996       Peter Williams
 Copyright (C) 1997, 1999 Gerald L. Gay
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(xarm_combobox_h)
#define xarm_combobox_h

/* ======================================================================= */
/* Include(s): */

#include <Xarm/Xarm.h>
#include <Xarm/Manager.h>
#include <Xarm/List.h>

/* 
* The ComboBox only exists in versions of Motif >= 2 and CDE. 
* However, you could write one yourself and remove this restriction.  
*/

#if XmVERSION >= 2 && ! defined(XARM_HAS_CDE)

#include <Xarm/M2ComboBox.h>
#define XARM_HAS_COMBOBOX

#elif defined(XARM_HAS_CDE)

#include <Xarm/CDEComboBox.h>
#define XARM_HAS_COMBOBOX

#endif


#endif
